Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/mcp9808_simpletest.py
    :caption: examples/mcp9808_simpletest.py
    :linenos:


Temperature Limit test
----------------------

Show the MCP9808 to setup different temperature values

.. literalinclude:: ../examples/mcp9808_temperature_limits.py
    :caption: examples/mcp9808_temperature_limits.py
    :linenos:
